@@ -164,9 +164,10 @@ void MainWindow::readSettings() {
     speedList = cameraSettings.value("speed", QStringList()).toStringList();
     cameraSettings.endGroup();
     if(apertureList.isEmpty() || isoList.isEmpty() || speedList.isEmpty()) {
+        settings.setValue("camera", QString("D80 0.3EV"));
+        settings.setValue("lens", QString("Nikkor DX AF-S 16-85mm 1:3.5-5.6G ED VR 0.3EV"));
         QMessageBox::critical(this, tr("Configuration problem"),
-                                    tr("I've deleted the user configuration for you. Try to restart, if the problem persist reinstall the app."));
-        settings.clear();
+                                    tr("Please restart. If the problem persist reinstall the app."));
         qApp->quit();
     }
     ui->lcdNumberAperture->setType(apertureList, tr("Choose Aperture"), tr("Aperture:"));
